@@ -29,6 +29,8 @@ CMACDlg::CMACDlg(CStringArrayEx * paryFiles, CWnd * pParent) :
     m_bLastLoadMenuAndToolbarProcessing = false;
     m_bInitialized = false;
     m_hAcceleratorTable = APE_NULL;
+    m_nMonitorDPI = 0;
+    m_nFontHeight = 0;
 
     m_hIcon = AfxGetApp()->LoadIcon(IDR_MAINFRAME);
 }
@@ -893,7 +895,9 @@ void CMACDlg::OnToolsOptions()
     COptionsDlg dlgOptions(this);
     if (dlgOptions.DoModal() == IDOK)
     {
-        // update settings...
+        // we need to reload the size and font since the scale numbers could change
+        // we need to force load since it only checks for a scale change but when the font size changes it also needs to reload
+        LoadScale(true);
     }
 }
 
@@ -902,7 +906,7 @@ int CMACDlg::GetScaledFontHeight(int nStart)
     // get size
     //nStart = theApp.GetSize(nStart); // no need to do this because the font is already sized for the scale
     double dHeight = static_cast<double>(nStart);
-    dHeight = dHeight * static_cast<double>(theApp.GetFontHeight()) / 12.0;
+    dHeight = dHeight * static_cast<double>(m_nFontHeight) / 15.0;
     int nHeight = static_cast<int>(dHeight);
     return nHeight;
 }
@@ -1030,6 +1034,22 @@ void CMACDlg::WinHelp(DWORD_PTR, UINT nCmd)
         OnHelpHelp();
 }
 
+int CMACDlg::GetControlHeight(CWnd * pwndControl)
+{
+    // get the height
+    int nHeight = GetScaledFontHeight(22);
+
+    // switch the height for static controls
+    CString strClass;
+    GetClassName(pwndControl->GetSafeHwnd(), strClass.GetBuffer(256), 255);
+    strClass.ReleaseBuffer();
+
+    if (strClass.CompareNoCase(_T("static")) == 0)
+        nHeight = m_nFontHeight;
+
+    return nHeight;
+}
+
 void CMACDlg::LayoutControlTop(CWnd * pwndLayout, CRect & rectLayout, bool bOnlyControlWidth, bool bCombobox, CWnd * pwndRight)
 {
     if (pwndLayout == APE_NULL)
@@ -1039,7 +1059,7 @@ void CMACDlg::LayoutControlTop(CWnd * pwndLayout, CRect & rectLayout, bool bOnly
     pwndLayout->GetWindowRect(&rectWindow);
 
     // make a standard height
-    rectWindow.bottom = rectWindow.top + GetScaledFontHeight(22);
+    rectWindow.bottom = rectWindow.top + GetControlHeight(pwndLayout);
 
     // layout
     CRect rectRight;
@@ -1073,6 +1093,7 @@ void CMACDlg::LayoutControlTopWithDivider(CWnd * pwndLayout, CWnd * pwndDivider,
     if (pwndLayout == APE_NULL)
         return;
 
+    // get window sizes
     CRect rectWindow;
     pwndLayout->GetWindowRect(&rectWindow);
     CRect rectDivider;
@@ -1084,13 +1105,13 @@ void CMACDlg::LayoutControlTopWithDivider(CWnd * pwndLayout, CWnd * pwndDivider,
     CString strWindowText;
     pwndLayout->GetWindowText(strWindowText);
     CDC * pDC = pwndLayout->GetDC();
-    pDC->SelectObject(GetFont());
+    pDC->SelectObject(theApp.GetFont());
     CSize sizeText = pDC->GetTextExtent(strWindowText);
     pwndLayout->ReleaseDC(pDC);
     rectWindow.right = rectWindow.left + sizeText.cx + theApp.GetSize(8);
 
     // make a standard height
-    rectWindow.bottom = rectWindow.top + GetScaledFontHeight(22);
+    rectWindow.bottom = rectWindow.top + GetControlHeight(pwndLayout);
 
     // layout
     pwndLayout->SetWindowPos(APE_NULL, rectLayout.left, rectLayout.top, rectWindow.Width(), rectWindow.Height(), SWP_NOZORDER);
@@ -1118,7 +1139,7 @@ void CMACDlg::PlayDefaultSound()
     }
 }
 
-void CMACDlg::LoadScale()
+void CMACDlg::LoadScale(bool bForce)
 {
     // default to 1.0
     double dScale = 1.0;
@@ -1150,8 +1171,18 @@ void CMACDlg::LoadScale()
     //dScale = 2.0; // test for high scales
     //dScale = 3.0;
     //dScale = 4.0;
-    if (theApp.SetScale(dScale) == false)
-        return; // do nothing if the scale didn't change
+    if (theApp.SetScale(dScale, bForce) == false)
+    {
+        if (bForce == false)
+            return; // do nothing if the scale didn't change
+    }
+
+    // get the text height (greater than the log font height)
+    CPaintDC dc(this);
+    dc.SelectObject(theApp.GetFont());
+    TEXTMETRIC Metrics; APE_CLEAR(Metrics);
+    dc.GetTextMetrics(&Metrics);
+    m_nFontHeight = Metrics.tmHeight;
 
     // release store image lists
     theApp.DeleteImageLists();
@@ -1198,6 +1229,9 @@ void CMACDlg::LoadScale()
     // set uniform widths so the buttons don't change size when we change the text
     int nButtonWidth = theApp.GetSize(40) + GetScaledFontHeight(42);
     m_ctrlToolbar.GetToolBarCtrl().SetButtonWidth(nButtonWidth, nButtonWidth);
+
+    // resize to get the right toolbar height
+    LayoutWindow();
 }
 
 void CMACDlg::FilesChanged(MAC_FILE_ARRAY * paryFiles)
@@ -1245,10 +1279,10 @@ void CMACDlg::UpdateEnabledStates()
     APE_CLEAR(aryTypeData);
     MenuInfo.dwTypeData = aryTypeData; // use type data pointer and copy the strings into this buffer
 
-    _tcscpy_s(aryTypeData, 1024, bHasMultipleFiles ? _T("Process Files\tEnter") : _T("Process File\tEnter"));
+    wcscpy_s(aryTypeData, 1024, bHasMultipleFiles ? L"Process Files\tEnter" : L"Process File\tEnter");
     GetMenu()->SetMenuItemInfo(ID_FILE_PROCESS_FILES, &MenuInfo, 0);
 
-    _tcscpy_s(aryTypeData, 1024, bHasMultipleSelection ? _T("Remove Files\tCtrl+R") : _T("Remove File\tCtrl+R"));
+    wcscpy_s(aryTypeData, 1024, bHasMultipleSelection ? L"Remove Files\tCtrl+R" : L"Remove File\tCtrl+R");
     GetMenu()->SetMenuItemInfo(ID_FILE_REMOVE_FILES, &MenuInfo, 0);
 
     // update toolbar button for remove files
