@@ -14,7 +14,7 @@ COptionsOutputDlg::COptionsOutputDlg(CMACDlg * pMACDlg, OPTIONS_PAGE * pPage, CW
     m_bMirrorTimeStamp = false;
 }
 
-void COptionsOutputDlg::DoDataExchange(CDataExchange* pDX)
+void COptionsOutputDlg::DoDataExchange(CDataExchange * pDX)
 {
     CDialog::DoDataExchange(pDX);
     DDX_Control(pDX, IDC_OTHER_PICTURE, m_ctrlOtherPicture);
@@ -47,8 +47,8 @@ BOOL COptionsOutputDlg::OnInitDialog()
     CDialog::OnInitDialog();
 
     // set the font to all the controls
-    SetFont(&m_pMACDlg->GetFont());
-    SendMessageToDescendants(WM_SETFONT, reinterpret_cast<WPARAM>(m_pMACDlg->GetFont().GetSafeHandle()), MAKELPARAM(false, 0), true);
+    SetFont(theApp.GetFont());
+    SendMessageToDescendants(WM_SETFONT, reinterpret_cast<WPARAM>(theApp.GetFont()->GetSafeHandle()), MAKELPARAM(false, 0), true);
 
     // images
     HICON hIcon = theApp.GetImageList(CMACApp::Image_OptionsPages)->ExtractIcon(TBB_OPTIONS_OUTPUT_LOCATION);
@@ -82,10 +82,6 @@ BOOL COptionsOutputDlg::OnInitDialog()
     // layout
     Layout();
 
-    // update our size
-    //CRect rectWindow; GetWindowRect(&rectWindow);
-    //SetWindowPos(APE_NULL, 0, 0, rectWindow.Width(), m_pPage->m_nIdealHeight + theApp.GetSize(128, 0).cx, SWP_NOMOVE);
-
     // update
     UpdateData(false);
     UpdateDialogState();
@@ -192,12 +188,10 @@ void COptionsOutputDlg::OnOutputLocationRecreateDirectoryStructureCheck()
 
 void COptionsOutputDlg::OnOK()
 {
-
 }
 
 void COptionsOutputDlg::OnCancel()
 {
-
 }
 
 void COptionsOutputDlg::Layout()
