@@ -68,7 +68,7 @@ CInputSource * CInputSource::CreateInputSource(const str_utfn * pSourceName, WAV
         spIO.SetDelete(false);
         if (pAIFF->GetIsBigEndian())
             *pFlags |= APE_FORMAT_FLAG_BIG_ENDIAN;
-        if ((pwfeSource->wBitsPerSample == 8) && pAIFF->m_bSigned8Bit)
+        if ((pwfeSource->wBitsPerSample == 8) && pAIFF->GetIsSigned8Bit())
             *pFlags |= APE_FORMAT_FLAG_SIGNED_8_BIT;
         if (pwfeSource->wFormatTag == WAVE_FORMAT_IEEE_FLOAT)
             *pFlags |= APE_FORMAT_FLAG_FLOATING_POINT;
@@ -960,6 +960,11 @@ bool CAIFFInputSource::GetIsBigEndian() const
     return !m_bLittleEndian;
 }
 
+bool CAIFFInputSource::GetIsSigned8Bit() const
+{
+    return m_bSigned8Bit;
+}
+
 /**************************************************************************************************
 CW64InputSource - wraps working with W64 files
 **************************************************************************************************/
